Reports
Reports
Export
Export specified report to a specified format
User with Execute Export permission on prepared report and Create Entity on an export folder can access this method.
Request
POST /api/rp/v1/Reports/File/{id}/Export
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | report id |
|
| body | export parameters |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified report has been exported |
|
| 204 | Specified report has been exported |
|
| 400 | Report Id is null |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Exports folder not found |
StaticPreview
Make preview for the report. Generate a new or return exist prepared svg files. If template was changed will be returned a new. Pass the `` parameter to check prepared timestamp
Request
POST /api/rp/v1/Reports/File/{id}/StaticPreview
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | template id |
|
| body | Model with parameters |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified template has been prepared |
|
| 204 | Specified template has been prepared |
|
| 400 | Template Id is null |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Template or folder not found |
UploadFileV2
Alternative api for upload a file to the specified folder!
User with Create Entity permission can access this method.
Request
POST /api/rp/v2/Reports/Folder/{id}/File
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of folder |
|
| TemplateId | string | User with Create Entity permission can access this method. |
|
| Tags | array | User with Create Entity permission can access this method. |
|
| Icon | file | User with Create Entity permission can access this method. |
|
| *FileContent | file | User with Create Entity permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | File has been uploaded |
|
| 400 | fileVM view model is not valid |
|
| 403 | You don't have permissions for the operation |
|
| 402 | subscription is outdated |
|
| 404 | folder/subscription is not found |
GetByTaskMessageId
Get report by specified task message id
Request
GET /api/rp/v1/Reports/File/TaskMessage/{taskMessageId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *taskMessageId | string | task message id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Report is found |
|
| 400 | id is not valid |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Report or subscription is not found |
|
| 500 | Try again, if error still here - text our support |
GetByTaskId
Get reports by specified task id
Request
GET /api/rp/v1/Reports/File/Task/{taskId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *taskId | string | task id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Reports are found |
|
| 400 | id is not valid |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Report or subscription is not found |
|
| 500 | Try again, if error still here - text our support |
CopyFile
Copy a file into a specified folder
Request
POST /api/rp/v1/Reports/File/{id}/Copy/{folderId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| *folderId | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File, folder or a subscription was not found |
CreateSharingKey
Create a new key, that can be used to share access to a file
(You need Administrate.Anon permission to create a new key)
Request
POST /api/rp/v1/Reports/File/{id}/sharingKey
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| body | parameters for sharing key creation |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 403 | You don't have permissions for the operation |
|
| 402 | Subscription is outdated |
|
| 404 | File or subscription was not found |
DeleteSharingKey
Deletes a sharing key, making links, that utilizing it no longer work
Request
DELETE /api/rp/v1/Reports/File/{id}/sharingKey
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| *key | string | key to delete |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File, sharing key or subscription was not found |
GetSharingKeys
Returns all sharing keys, associated with the file
Request
GET /api/rp/v1/Reports/File/{id}/sharingKeys
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
DeleteFile
Delete specified file
User with Delete permission can access the method.
Request
DELETE /api/rp/v1/Reports/File/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
GetFile
Get specified file
User with Get Entity permission can access this method.
Request
GET /api/rp/v1/Reports/File/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
MoveFileToBin
Move specified file to recycle bin
User with Delete permission can access the method.
Request
DELETE /api/rp/v1/Reports/File/{id}/ToBin
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
RecoverFile
Recover specified file from bin
Request
POST /api/rp/v1/Reports/File/{id}/Recover[?recoveryPath]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| recoveryPath | string | id of the folder, where the file should be restored to |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
GetFileHistory
Returns list of actions, performed on this file
Request
GET /api/rp/v1/Reports/File/{id}/History[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| skip | integer | 0 | how many actions to skip |
| take | integer | 10 | how many actions to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
GetFilesCount
Get count of files what contains in a specified folder
User with Get Count permission can access this method.
Request
GET /api/rp/v1/Reports/Folder/{id}/CountFiles
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
GetFilesList
Get files from the specified folder
User with a Get Entity permission can access this method.
Request
GET /api/rp/v1/Reports/Folder/{id}/ListFiles[?skip&take&searchPattern&orderBy&desc&useRegex]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| skip | integer | 0 | number of files to skip |
| take | integer | 10 | number of files to take |
| searchPattern | string | search pattern used to only include matching files in the result |
|
| orderBy | a field to sort by |
||
| desc | boolean | False | if true - sorting will be done in the descending order, otherwise - ascending |
| useRegex | boolean | False | set this to true if you want to use regular expression to search |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or folder was not found |
GetPermissions
Get all permissions from a file.
Request
GET /api/rp/v1/Reports/File/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
UpdatePermissions
Update permissions
Request
POST /api/rp/v1/Reports/File/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| body | new permissions VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | No Content |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
|
| 200 | Success |
GetMyPermissions
Get current user's permissions to a file
Request
GET /api/rp/v1/Reports/File/{id}/mypermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
MoveFile
Move file to a specified folder
User with a Update Place permission for a folder and Create Entity for a Parent Folder can access this method.
Request
POST /api/rp/v1/Reports/File/{id}/Move/{folderId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | file id |
|
| *folderId | string | folder id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File, folder or subscription was not found |
RenameFile
Rename a file
User with Update Name permission can access this method.
Request
PUT /api/rp/v1/Reports/File/{id}/Rename
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | User with Update Name permission can access this method. |
|
| body | User with Update Name permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
UpdateIcon
Update a files's icon
User with Update Icon permission can access this method.
Request
PUT /api/rp/v1/Reports/File/{id}/Icon
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | User with Update Icon permission can access this method. |
|
| body | User with Update Icon permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
UpdateTags
Update tags
User with Update Tags permission can access this method.
Request
PUT /api/rp/v1/Reports/File/{id}/UpdateTags
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | User with Update Tags permission can access this method. |
|
| body | User with Update Tags permission can access this method. |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | File or subscription was not found |
UploadFile
Upload a file to the specified folder. The method is deprecated, use the UploadFileV2 method instead!
User with Create Entity permission can access this method.
Request
POST /api/rp/v1/Reports/Folder/{id}/File
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | folder id |
|
| body | new file's view model |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Provided parameters did not pass the validation |
|
| 403 | You don't have permissions for the operation |
|
| 402 | Subscription is outdated |
|
| 404 | Folder or subscription was not found |
Definitions
ExportReportVM
| Name | Type | Notes |
|---|---|---|
| fileName | string | |
| folderId | string | |
| locale | string | |
| pagesCount | integer (int32) | |
| format |
|
|
| exportParameters | object | |
| $t | string |
ExportFormat
Enum Values
PdfHtml
Mht
Image
Biff8
Csv
Dbf
Json
LaTeX
Odt
Ods
Docx
Pptx
Xlsx
Xps
Ppml
PS
Richtext
Svg
Text
Xaml
Xml
Zpl
ExportVM
| Name | Type | Notes |
|---|---|---|
| format |
|
|
| reportId | string | |
| templateId | string | |
| taskId | string | |
| taskMessageId | string | |
| $t | string | |
| id | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| name | string | |
| parentId | string | |
| tags | array | |
| icon | string (byte) | |
| type |
|
|
| size | integer (int64) | |
| subscriptionId | string | |
| status |
|
|
| statusReason |
|
|
| errorMessage | string | |
| isDeleted | boolean | |
| platform |
|
FileType
Enum Values
FileFolder
FileStatus
Enum Values
NoneInQueue
InProcess
Success
Failed
FileStatusReason
Enum Values
NoneAllRight
Hang
Error
NotFound
NotEnoughSpace
ExportStarted
PreparationStarted
CrashLoop
ReportPlatform
Enum Values
UnknownNET
VCL
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
PreviewReportVM
| Name | Type | Notes |
|---|---|---|
| locale | string | |
| cacheTolerance | number (double) | |
| $t | string |
ReportVM
| Name | Type | Notes |
|---|---|---|
| templateId | string | |
| reportInfo |
|
|
| taskId | string | |
| taskMessageId | string | |
| $t | string | |
| id | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| name | string | |
| parentId | string | |
| tags | array | |
| icon | string (byte) | |
| type |
|
|
| size | integer (int64) | |
| subscriptionId | string | |
| status |
|
|
| statusReason |
|
|
| errorMessage | string | |
| isDeleted | boolean | |
| platform |
|
ReportInfo
| Name | Type | Notes |
|---|---|---|
| author | string | |
| created | string (date-time) | |
| creatorVersion | string | |
| description | string | |
| modified | string (date-time) | |
| name | string | |
| picture | string (byte) | |
| previewPictureRatio | number (float) | |
| saveMode |
|
|
| savePreviewPicture | boolean | |
| tag | string | |
| version | string |
SaveMode
Enum Values
AllOriginal
User
Role
Security
Deny
Custom
ReportsVM
| Name | Type | Notes |
|---|---|---|
| files |
|
|
| $t | string | |
| count | integer (int64) | |
| skip | integer (int32) | |
| take | integer (int32) |
CreateFileShareVM
| Name | Type | Notes |
|---|---|---|
| expires | string (date-time) | |
| name | string | |
| permission |
|
|
| $t | string |
FilePermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
FileCreate
FileDelete
FileExecute
FileGet
FileUpdate
FileAdministrate
FileSharingKeysVM
| Name | Type | Notes |
|---|---|---|
| keys |
|
FileShareVM
| Name | Type | Notes |
|---|---|---|
| expires | string (date-time) | |
| name | string | |
| permission |
|
|
| key | string |
AuditActionsVM
| Name | Type | Notes |
|---|---|---|
| items |
|
|
| hasMore | boolean | |
| skip | integer (int32) | |
| take | integer (int32) | |
| $t | string |
AuditActionVM
| Name | Type | Notes |
|---|---|---|
| userId | string | |
| entityId | string | |
| subscriptionId | string | |
| type |
|
|
| id | string | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| name | string | |
| adminAction | boolean | |
| $t | string |
AuditType
Enum Values
Task_Created_ExportTemplateTask_Created_ExportReport
Task_Created_PrepareTemplate
Task_Created_Fetch
Task_Created_Email
Task_Created_Webhook
Task_Deleted_ExportTemplate
Task_Deleted_ExportReport
Task_Deleted_PrepareTemplate
Task_Deleted_Fetch
Task_Deleted_Email
Task_Deleted_Webhook
Task_Updated_ExportTemplate
Task_Updated_ExportReport
Task_Updated_PrepareTemplate
Task_Updated_Fetch
Task_Updated_Email
Task_Updated_Webhook
Task_InQueue_ExportTemplate
Task_InQueue_ExportReport
Task_InQueue_PrepareTemplate
Task_InQueue_Fetch
Task_InQueue_Email
Task_InQueue_Webhook
Task_InProcess_ExportTemplate
Task_InProcess_ExportReport
Task_InProcess_PrepareTemplate
Task_InProcess_Fetch
Task_InProcess_Email
Task_InProcess_Webhook
Task_Success_ExportTemplate
Task_Success_ExportReport
Task_Success_PrepareTemplate
Task_Success_Fetch
Task_Success_Email
Task_Success_Webhook
Task_Failed_ExportTemplate
Task_Failed_ExportReport
Task_Failed_PrepareTemplate
Task_Failed_Fetch
Task_Failed_Email
Task_Failed_Webhook
Task_Created_ThumbnailReport
Task_Deleted_ThumbnailReport
Task_Updated_ThumbnailReport
Task_InQueue_ThumbnailReport
Task_InProcess_ThumbnailReport
Task_Success_ThumbnailReport
Task_Fail_ThumbnailReport
Task_Created_ThumbnailTemplate
Task_Deleted_ThumbnailTemplate
Task_Updated_ThumbnailTemplate
Task_InQueue_ThumbnailTemplate
Task_InProcess_ThumbnailTemplate
Task_Success_ThumbnailTemplate
Task_Fail_ThumbnailTemplate
Subscription_Renewed
Subscription_Created
File_Renamed
File_Content_Updated
File_Deleted
File_Moved
File_Copied
File_Tags_Updated
File_Permissions_Updated
File_Restored
File_MovedToBin
File_Updated
Task_Created_FTPUpload
Task_Deleted_FTPUpload
Task_Updated_FTPUpload
Task_InQueue_FTPUpload
Task_InProcess_FTPUpload
Task_Success_FTPUpload
Task_Fail_FTPUpload
File_Created
Task_Created_S3Upload
Task_Deleted_S3Upload
Task_Updated_S3Upload
Task_InQueue_S3Upload
Task_InProcess_S3Upload
Task_Success_S3Upload
Task_Fail_S3Upload
Task_Created_TelegramUpload
Task_Deleted_TelegramUpload
Task_Updated_TelegramUpload
Task_InQueue_TelegramUpload
Task_InProcess_TelegramUpload
Task_Success_TelegramUpload
Task_Fail_TelegramUpload
CountVM
| Name | Type | Notes |
|---|---|---|
| count | integer (int64) | |
| $t | string |
FilePermissionsVM
| Name | Type | Notes |
|---|---|---|
| permissions |
|
|
| $t | string |
FilePermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
UpdateFilePermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
FileRenameVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| $t | string |
FileIconVM
| Name | Type | Notes |
|---|---|---|
| icon | string (byte) | |
| $t | string |
FileTagsUpdateVM
| Name | Type | Notes |
|---|---|---|
| tags | array | |
| $t | string |
ReportCreateVM
| Name | Type | Notes |
|---|---|---|
| templateId | string | |
| $t | string | |
| name | string | |
| tags | array | |
| icon | string (byte) | |
| content | string (byte) | |
| platform |
|